
# Slot: author


List of strings with the names of the authors of the namespace.

URI: [nwb_schema_language:author](https://w3id.org/p2p_ld/nwb-schema-language/author)


## Domain and Range

None &#8594;  <sub>1..\*</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Namespace](Namespace.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | schema:author |

